# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor_events.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sensor_events.proto',
  package='',
  serialized_pb=_b('\n\x13sensor_events.proto\"\xaa\x02\n\x0b\x43\x62HeaderMsg\x12\x0f\n\x07version\x18\x01 \x02(\x05\x12\x0e\n\x06\x62ootid\x18\x02 \x01(\x05\x12\x0f\n\x07\x65ventid\x18\x03 \x01(\x05\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x14\n\x0cprocess_guid\x18\x05 \x01(\x03\x12\x1c\n\x14\x66ilepath_string_guid\x18\x06 \x01(\x03\x12\r\n\x05magic\x18\x07 \x01(\r\x12$\n\x1cprocess_filepath_string_guid\x18\x08 \x01(\x03\x12\x1b\n\x13process_create_time\x18\t \x01(\x03\x12\x13\n\x0bprocess_pid\x18\n \x01(\x05\x12\x13\n\x0bprocess_md5\x18\x0b \x01(\x0c\x12\x14\n\x0cprocess_path\x18\x0c \x01(\t\x12\x10\n\x08\x66ork_pid\x18\r \x01(\x05\"\xb1\x01\n\x0b\x43\x62StringMsg\x12\x0c\n\x04guid\x18\x01 \x01(\x03\x12\x12\n\nutf8string\x18\x02 \x01(\x0c\x12<\n\x0bstring_type\x18\x03 \x01(\x0e\x32\x19.CbStringMsg.CbStringType:\x0ctypeFilepath\"B\n\x0c\x43\x62StringType\x12\x10\n\x0ctypeFilepath\x10\x01\x12\x0f\n\x0btypeRegpath\x10\x02\x12\x0f\n\x0btypeNetpath\x10\x03\"\xc4\x03\n\x0c\x43\x62ProcessMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x0f\n\x07\x63reated\x18\x02 \x01(\x08\x12\x12\n\nparent_pid\x18\x03 \x01(\x05\x12\x1a\n\x12parent_create_time\x18\x04 \x01(\x03\x12\x13\n\x0bparent_guid\x18\x05 \x01(\x03\x12\x0f\n\x07md5hash\x18\x06 \x01(\x0c\x12\x18\n\x10have_seen_before\x18\x07 \x01(\x08\x12\x12\n\ndeprecated\x18\x08 \x01(\x03\x12\x13\n\x0b\x63ommandline\x18\t \x01(\x0c\x12\x12\n\nparent_md5\x18\n \x01(\x0c\x12\x13\n\x0bparent_path\x18\x0b \x01(\t\x12\x1f\n\x10\x63reationobserved\x18\x0c \x01(\x08:\x05\x66\x61lse\x12$\n\x15\x65xpect_followon_w_md5\x18\r \x01(\x08:\x05\x66\x61lse\x12\x0b\n\x03uid\x18\x0e \x01(\t\x12\x10\n\x08username\x18\x0f \x01(\t\x12(\n\x07\x61\x63tions\x18\x10 \x03(\x0b\x32\x17.CbEmetMitigationAction\x12 \n\x11\x61\x63tionsAreFromGPO\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\"\n\x13\x62\x46ilteringKnownDlls\x18\x12 \x01(\x08:\x05\x66\x61lse\"\xca\x01\n\x10\x43\x62SuppressedInfo\x12\x1c\n\rbIsSuppressed\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x39\n\x05state\x18\x02 \x01(\x0e\x32*.CbSuppressedInfo.CbSuppressedProcessState\"]\n\x18\x43\x62SuppressedProcessState\x12\x1f\n\x1bsuppressedEventlessModloads\x10\x01\x12 \n\x1csuppressedEventlessWithXproc\x10\x02\"\x8e\x03\n\x11\x43\x62\x43hildProcessMsg\x12\x0f\n\x07\x63reated\x18\x01 \x01(\x08\x12\x13\n\x0bparent_guid\x18\x02 \x01(\x03\x12\x0f\n\x07md5hash\x18\x03 \x01(\x0c\x12\x12\n\nchild_guid\x18\x04 \x01(\x03\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x03\x12\x13\n\x0b\x63reate_time\x18\x07 \x01(\x03\x12\x15\n\x06tamper\x18\x08 \x01(\x08:\x05\x66\x61lse\x12%\n\nsuppressed\x18\t \x01(\x0b\x32\x11.CbSuppressedInfo\x12\x13\n\x0b\x63ommandline\x18\n \x01(\x0c\x12\x10\n\x08username\x18\x0b \x01(\t\x12H\n\rchildProcType\x18\x0c \x01(\x0e\x32\".CbChildProcessMsg.CbChildProcType:\rchildProcExec\"O\n\x0f\x43\x62\x43hildProcType\x12\x11\n\rchildProcExec\x10\x00\x12\x11\n\rchildProcFork\x10\x01\x12\x16\n\x12\x63hildProcOtherExec\x10\x02\"\xa8\x01\n\x0f\x43\x62ModuleLoadMsg\x12\x0c\n\x04guid\x18\x01 \x01(\x03\x12\x1e\n\x16handlepath_string_guid\x18\x02 \x01(\x03\x12\x0f\n\x07md5hash\x18\x03 \x01(\x0c\x12\x0e\n\x06scanid\x18\x04 \x01(\x05\x12\x1e\n\x16is_process_base_module\x18\x05 \x01(\x08\x12\x12\n\nimage_base\x18\x06 \x01(\x03\x12\x12\n\nimage_size\x18\x07 \x01(\r\"\x91\x05\n\x0c\x43\x62\x46ileModMsg\x12\x0c\n\x04guid\x18\x01 \x01(\x03\x12-\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1d.CbFileModMsg.CbFileModAction\x12\x18\n\x10have_seen_before\x18\x03 \x01(\x08\x12\x0f\n\x07md5hash\x18\x04 \x01(\x0c\x12&\n\x04type\x18\x05 \x01(\x0e\x32\x18.CbFileModMsg.CbFileType\x12\x15\n\x06tamper\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x8e\x01\n\x0f\x43\x62\x46ileModAction\x12\x17\n\x13\x61\x63tionFileModCreate\x10\x01\x12\x16\n\x12\x61\x63tionFileModWrite\x10\x02\x12\x17\n\x13\x61\x63tionFileModDelete\x10\x04\x12\x1a\n\x16\x61\x63tionFileModLastWrite\x10\x08\x12\x15\n\x11\x61\x63tionFileModOpen\x10\x10\"\xc8\x02\n\nCbFileType\x12\x13\n\x0f\x66iletypeUnknown\x10\x00\x12\x0e\n\nfiletypePe\x10\x01\x12\x0f\n\x0b\x66iletypeElf\x10\x02\x12\x18\n\x14\x66iletypeUniversalBin\x10\x03\x12\x11\n\rfiletypeEicar\x10\x08\x12\x18\n\x14\x66iletypeOfficeLegacy\x10\x10\x12\x19\n\x15\x66iletypeOfficeOpenXml\x10\x11\x12\x0f\n\x0b\x66iletypePdf\x10\x30\x12\x18\n\x14\x66iletypeArchivePkzip\x10@\x12\x16\n\x12\x66iletypeArchiveLzh\x10\x41\x12\x16\n\x12\x66iletypeArchiveLzw\x10\x42\x12\x16\n\x12\x66iletypeArchiveRar\x10\x43\x12\x16\n\x12\x66iletypeArchiveTar\x10\x44\x12\x17\n\x13\x66iletypeArchive7zip\x10\x45\"\x90\x02\n\x0b\x43\x62RegModMsg\x12\x0c\n\x04guid\x18\x01 \x01(\x03\x12+\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1b.CbRegModMsg.CbRegModAction\x12\x18\n\x10have_seen_before\x18\x03 \x01(\x08\x12\x14\n\x0cutf8_regpath\x18\x04 \x01(\x0c\x12\x15\n\x06tamper\x18\x05 \x01(\x08:\x05\x66\x61lse\"\x7f\n\x0e\x43\x62RegModAction\x12\x19\n\x15\x61\x63tionRegModCreateKey\x10\x01\x12\x1a\n\x16\x61\x63tionRegModWriteValue\x10\x02\x12\x19\n\x15\x61\x63tionRegModDeleteKey\x10\x04\x12\x1b\n\x17\x61\x63tionRegModDeleteValue\x10\x08\"\xaa\x03\n\x0c\x43\x62NetConnMsg\x12\x0c\n\x04guid\x18\x01 \x01(\x03\x12\x13\n\x0bipv4Address\x18\x02 \x01(\r\x12\x12\n\nipv6LoPart\x18\x03 \x01(\x04\x12\x12\n\nipv6HiPart\x18\x04 \x01(\x04\x12\x0c\n\x04port\x18\x05 \x01(\r\x12,\n\x08protocol\x18\x06 \x01(\x0e\x32\x1a.CbNetConnMsg.ProtocolType\x12\x14\n\x0cutf8_netpath\x18\x07 \x01(\x0c\x12\x16\n\x08outbound\x18\x08 \x01(\x08:\x04true\x12\x1e\n\x0fproxyConnection\x18\t \x01(\x08:\x05\x66\x61lse\x12\x18\n\x10proxyIpv4Address\x18\n \x01(\r\x12\x11\n\tproxyPort\x18\x0b \x01(\r\x12\x14\n\x0cproxyNetPath\x18\x0c \x01(\t\x12\x17\n\x0fremoteIpAddress\x18\r \x01(\r\x12\x12\n\nremotePort\x18\x0e \x01(\r\x12\x16\n\x0elocalIpAddress\x18\x0f \x01(\r\x12\x11\n\tlocalPort\x18\x10 \x01(\r\"*\n\x0cProtocolType\x12\x0c\n\x08ProtoTcp\x10\x06\x12\x0c\n\x08ProtoUdp\x10\x11\"\xea\x01\n\rCbLinStatsMsg\x12\x11\n\tlin_total\x18\x01 \x01(\x05\x12\x16\n\x0elin_successful\x18\x02 \x01(\x05\x12\x16\n\x0elin_no_scanidi\x18\x03 \x01(\x05\x12\x18\n\x10lin_total_pended\x18\x04 \x01(\x05\x12&\n\x1elin_current_scanid_pended_size\x18\x05 \x01(\x05\x12*\n\"lin_current_handlepath_pended_size\x18\x06 \x01(\x05\x12(\n lin_current_filepath_pended_size\x18\x07 \x01(\x05\"\xf8\x01\n\x15\x43\x62\x43rossProcessOpenMsg\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.CbCrossProcessOpenMsg.OpenType\x12\x11\n\ttargetPid\x18\x02 \x01(\r\x12\x1c\n\x14targetProcCreateTime\x18\x03 \x01(\x04\x12\x17\n\x0frequestedAccess\x18\x04 \x01(\r\x12\x16\n\x0etargetProcPath\x18\x05 \x01(\t\x12\x15\n\rtargetProcMd5\x18\x06 \x01(\x0c\"7\n\x08OpenType\x12\x15\n\x11OpenProcessHandle\x10\x01\x12\x14\n\x10OpenThreadHandle\x10\x02\"}\n\x17\x43\x62\x43reateRemoteThreadMsg\x12\x15\n\rremoteProcPid\x18\x01 \x01(\r\x12\x1c\n\x14remoteProcCreateTime\x18\x02 \x01(\x04\x12\x16\n\x0eremoteProcPath\x18\x03 \x01(\t\x12\x15\n\rremoteProcMd5\x18\x04 \x01(\x0c\"\x8b\x01\n\x11\x43\x62\x43rossProcessMsg\x12$\n\x04open\x18\x01 \x01(\x0b\x32\x16.CbCrossProcessOpenMsg\x12.\n\x0cremotethread\x18\x02 \x01(\x0b\x32\x18.CbCreateRemoteThreadMsg\x12\x0e\n\x06tamper\x18\x03 \x01(\x08\x12\x10\n\x08isTarget\x18\x04 \x01(\x08\"\xb1\x05\n\x13\x43\x62ProcessBlockedMsg\x12\x33\n\x0b\x62lockedType\x18\x01 \x01(\x0e\x32\x1e.CbProcessBlockedMsg.BlockType\x12\x35\n\x0c\x62lockedEvent\x18\x02 \x01(\x0e\x32\x1f.CbProcessBlockedMsg.BlockEvent\x12\x16\n\x0e\x62lockedmd5Hash\x18\x03 \x01(\x0c\x12\x13\n\x0b\x62lockedPath\x18\x04 \x01(\t\x12\x35\n\x0b\x62lockResult\x18\x05 \x01(\x0e\x32 .CbProcessBlockedMsg.BlockResult\x12\x12\n\nblockError\x18\x06 \x01(\r\x12\x12\n\nblockedPid\x18\x07 \x01(\x05\x12\x1d\n\x15\x62lockedProcCreateTime\x18\x08 \x01(\x04\x12\x16\n\x0e\x62lockedCmdline\x18\t \x01(\t\x12\x12\n\nblockedUid\x18\n \x01(\t\x12\x17\n\x0f\x62lockedUsername\x18\x0b \x01(\t\"\x18\n\tBlockType\x12\x0b\n\x07MD5Hash\x10\x01\"3\n\nBlockEvent\x12\x11\n\rProcessCreate\x10\x01\x12\x12\n\x0eRunningProcess\x10\x02\"\xee\x01\n\x0b\x42lockResult\x12\x15\n\x11ProcessTerminated\x10\x00\x12\x1a\n\x16NotTerminatedCBProcess\x10\x01\x12\x1e\n\x1aNotTerminatedSystemProcess\x10\x02\x12&\n\"NotTerminatedCriticalSystemProcess\x10\x03\x12 \n\x1cNotTerminatedWhitelistedPath\x10\x04\x12!\n\x1dNotTerminatedOpenProcessError\x10\x05\x12\x1f\n\x1bNotTerminatedTerminateError\x10\x06\"\x90\x04\n\x13\x43\x62NetConnBlockedMsg\x12:\n\x0b\x62lockedType\x18\x01 \x01(\x0e\x32%.CbNetConnBlockedMsg.NetconnBlockType\x12\x13\n\x0bipv4Address\x18\x02 \x01(\r\x12\x12\n\nipv6LoPart\x18\x03 \x01(\x04\x12\x12\n\nipv6HiPart\x18\x04 \x01(\x04\x12\x0c\n\x04port\x18\x05 \x01(\r\x12\x33\n\x08protocol\x18\x06 \x01(\x0e\x32!.CbNetConnBlockedMsg.ProtocolType\x12\x14\n\x0cutf8_netpath\x18\x07 \x01(\x0c\x12\x16\n\x08outbound\x18\x08 \x01(\x08:\x04true\x12\x1e\n\x0fproxyConnection\x18\t \x01(\x08:\x05\x66\x61lse\x12\x18\n\x10proxyIpv4Address\x18\n \x01(\r\x12\x11\n\tproxyPort\x18\x0b \x01(\r\x12\x14\n\x0cproxyNetPath\x18\x0c \x01(\t\x12\x17\n\x0fremoteIpAddress\x18\r \x01(\r\x12\x12\n\nremotePort\x18\x0e \x01(\r\x12\x16\n\x0elocalIpAddress\x18\x0f \x01(\r\x12\x11\n\tlocalPort\x18\x10 \x01(\r\"(\n\x10NetconnBlockType\x12\x14\n\x10NetworkIsolation\x10\x01\"*\n\x0cProtocolType\x12\x0c\n\x08ProtoTcp\x10\x06\x12\x0c\n\x08ProtoUdp\x10\x11\"4\n\x0f\x43\x62StatisticsMsg\x12!\n\tlin_stats\x18\x01 \x01(\x0b\x32\x0e.CbLinStatsMsg\"\xe2\x05\n\x0f\x43\x62ModuleInfoMsg\x12\x0b\n\x03md5\x18\x01 \x01(\x0c\x12\x1a\n\x12\x43opiedModuleLength\x18\x02 \x01(\r\x12\x1c\n\x14OriginalModuleLength\x18\x03 \x01(\x04\x12\x1c\n\x14utf8_FileDescription\x18\x04 \x01(\t\x12\x18\n\x10utf8_CompanyName\x18\x05 \x01(\t\x12\x18\n\x10utf8_ProductName\x18\x06 \x01(\t\x12\x18\n\x10utf8_FileVersion\x18\x07 \x01(\t\x12\x15\n\rutf8_Comments\x18\x08 \x01(\t\x12\x1b\n\x13utf8_LegalCopyright\x18\t \x01(\t\x12\x1b\n\x13utf8_LegalTrademark\x18\n \x01(\t\x12\x19\n\x11utf8_InternalName\x18\x0b \x01(\t\x12\x1d\n\x15utf8_OriginalFileName\x18\x0c \x01(\t\x12\x1f\n\x17utf8_ProductDescription\x18\r \x01(\t\x12\x1b\n\x13utf8_ProductVersion\x18\x0e \x01(\t\x12\x19\n\x11utf8_PrivateBuild\x18\x0f \x01(\t\x12\x19\n\x11utf8_SpecialBuild\x18\x10 \x01(\t\x12\x1d\n\x15utf8_DigSig_Publisher\x18\x11 \x01(\t\x12\x1f\n\x17utf8_DigSig_ProgramName\x18\x12 \x01(\t\x12\x1e\n\x16utf8_DigSig_IssuerName\x18\x13 \x01(\t\x12\x1f\n\x17utf8_DigSig_SubjectName\x18\x14 \x01(\t\x12\x1a\n\x12utf8_DigSig_Result\x18\x15 \x01(\t\x12\x1e\n\x16utf8_DigSig_ResultCode\x18\x16 \x01(\t\x12\x1c\n\x14utf8_DigSig_SignTime\x18\x17 \x01(\t\x12\x0c\n\x04Icon\x18\x18 \x01(\x0c\x12\x17\n\x0fImageFileHeader\x18\x19 \x01(\x0c\x12\x1b\n\x13utf8_OnDiskFilename\x18\x1a \x01(\t\"\xa4\x01\n\x0c\x43\x62VtWriteMsg\x12\x1c\n\x14WritingProcessExeMd5\x18\x01 \x01(\x0c\x12\x16\n\x0e\x46ileWrittenMd5\x18\x02 \x01(\x0c\x12!\n\x19\x46ileWrittenIsPeModuleHint\x18\x03 \x01(\x08\x12\x1e\n\x16WritingProcessFilename\x18\x04 \x01(\t\x12\x1b\n\x13\x46ileWrittenFilename\x18\x05 \x01(\t\"C\n\x0b\x43\x62VtLoadMsg\x12\x1b\n\x13LoaderProcessExeMd5\x18\x01 \x01(\x0c\x12\x17\n\x0fLoadedModuleMd5\x18\x02 \x01(\x0c\"T\n\x18\x43\x62\x45ndpointEnvironmentMsg\x12\x10\n\x08SensorId\x18\x01 \x01(\x05\x12\x16\n\x0eSensorHostName\x18\x02 \x01(\t\x12\x0e\n\x06HostId\x18\x03 \x01(\x03\"(\n\x16\x43\x62ServerEnvironmentMsg\x12\x0e\n\x06NodeId\x18\x01 \x01(\x05\"h\n\x10\x43\x62\x45nvironmentMsg\x12+\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x19.CbEndpointEnvironmentMsg\x12\'\n\x06server\x18\x02 \x01(\x0b\x32\x17.CbServerEnvironmentMsg\"\xeb\x01\n\x10\x43\x62TamperAlertMsg\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.CbTamperAlertMsg.CbTamperAlertType\"\xa3\x01\n\x11\x43\x62TamperAlertType\x12\x1b\n\x17\x41lertCoreDriverUnloaded\x10\x01\x12\x1e\n\x1a\x41lertNetworkDriverUnloaded\x10\x02\x12\x19\n\x15\x41lertCbServiceStopped\x10\x03\x12\x1c\n\x18\x41lertCbProcessTerminated\x10\x04\x12\x18\n\x14\x41lertCbCodeInjection\x10\x05\"\xf8\x03\n\x16\x43\x62\x45metMitigationAction\x12\x45\n\x0emitigationType\x18\x01 \x01(\x0e\x32-.CbEmetMitigationAction.CbEmetMitigationTypes\"\x96\x03\n\x15\x43\x62\x45metMitigationTypes\x12\r\n\tactionDep\x10\x01\x12\x0f\n\x0b\x61\x63tionSehop\x10\x02\x12\r\n\tactionAsr\x10\x03\x12\x0e\n\nactionAslr\x10\x04\x12\x12\n\x0e\x61\x63tionNullPage\x10\x05\x12\x13\n\x0f\x61\x63tionHeapSpray\x10\x06\x12\x17\n\x13\x61\x63tionMandatoryAslr\x10\x07\x12\r\n\tactionEaf\x10\x08\x12\x11\n\ractionEafPlus\x10\t\x12\x16\n\x12\x61\x63tionBottomUpAslr\x10\n\x12\x15\n\x11\x61\x63tionLoadLibrary\x10\x0b\x12\x1a\n\x16\x61\x63tionMemoryProtection\x10\x0c\x12\x1a\n\x16\x61\x63tionSimulateExecFlow\x10\r\x12\x14\n\x10\x61\x63tionStackPivot\x10\x0e\x12\x16\n\x12\x61\x63tionCallerChecks\x10\x0f\x12\x19\n\x15\x61\x63tionBannedFunctions\x10\x10\x12\x13\n\x0f\x61\x63tionDeepHooks\x10\x11\x12\x15\n\x11\x61\x63tionAntiDetours\x10\x12\"\x90\x01\n\x13\x43\x62\x45metMitigationMsg\x12\x0e\n\x06\x65metId\x18\x01 \x01(\x04\x12\x14\n\x0c\x65metTimstamp\x18\x02 \x01(\x04\x12\'\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x17.CbEmetMitigationAction\x12\x12\n\nactionText\x18\x04 \x01(\t\x12\x16\n\x07\x62locked\x18\x05 \x01(\x08:\x05\x66\x61lse\"\xa7\x04\n\x14\x43\x62ProcessMetadataMsg\x12\x14\n\x0cprocess_guid\x18\x01 \x01(\x03\x12\x1b\n\x13process_create_time\x18\x02 \x01(\x03\x12\x13\n\x0bprocess_pid\x18\x03 \x01(\x05\x12\x13\n\x0bprocess_md5\x18\x04 \x01(\x0c\x12\x14\n\x0cprocess_path\x18\x05 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x13\n\x0b\x63ommandline\x18\x08 \x01(\x0c\x12\x12\n\nparent_pid\x18\t \x01(\x05\x12\x1a\n\x12parent_create_time\x18\n \x01(\x03\x12\x12\n\nparent_md5\x18\x0b \x01(\x0c\x12\x13\n\x0bparent_path\x18\x0c \x01(\t\x12\x15\n\rmodload_count\x18\r \x01(\x05\x12\x15\n\rfilemod_count\x18\x0e \x01(\x05\x12\x15\n\rnetconn_count\x18\x0f \x01(\x05\x12\x14\n\x0cregmod_count\x18\x10 \x01(\x05\x12\x17\n\x0f\x63hildproc_count\x18\x11 \x01(\x05\x12\x17\n\x0f\x63rossproc_count\x18\x12 \x01(\x05\x12\x12\n\nemet_count\x18\x13 \x01(\x05\x12\x1a\n\x12processblock_count\x18\x14 \x01(\x05\x12\x19\n\x11sensor_start_time\x18\x15 \x01(\x03\x12\x16\n\x0esensor_segment\x18\x16 \x01(\x03\x12\x1f\n\x10\x63reationobserved\x18\x17 \x01(\x08:\x05\x66\x61lse\"\xa6\x05\n\nCbEventMsg\x12\x1c\n\x06header\x18\x01 \x02(\x0b\x32\x0c.CbHeaderMsg\x12\x1d\n\x07strings\x18\x02 \x03(\x0b\x32\x0c.CbStringMsg\x12\x1e\n\x07process\x18\x03 \x01(\x0b\x32\r.CbProcessMsg\x12!\n\x07modload\x18\x04 \x01(\x0b\x32\x10.CbModuleLoadMsg\x12\x1e\n\x07\x66ilemod\x18\x05 \x01(\x0b\x32\r.CbFileModMsg\x12\x1e\n\x07network\x18\x06 \x01(\x0b\x32\r.CbNetConnMsg\x12\x1c\n\x06regmod\x18\x07 \x01(\x0b\x32\x0c.CbRegModMsg\x12\x1f\n\x05stats\x18\x08 \x01(\x0b\x32\x10.CbStatisticsMsg\x12 \n\x06module\x18\t \x01(\x0b\x32\x10.CbModuleInfoMsg\x12\x1e\n\x07vtwrite\x18\n \x01(\x0b\x32\r.CbVtWriteMsg\x12\x1c\n\x06vtload\x18\x0b \x01(\x0b\x32\x0c.CbVtLoadMsg\x12%\n\tchildproc\x18\x0c \x01(\x0b\x32\x12.CbChildProcessMsg\x12\x1e\n\x03\x65nv\x18\r \x01(\x0b\x32\x11.CbEnvironmentMsg\x12%\n\tcrossproc\x18\x0e \x01(\x0b\x32\x12.CbCrossProcessMsg\x12&\n\x0btamperAlert\x18\x0f \x01(\x0b\x32\x11.CbTamperAlertMsg\x12%\n\x07\x62locked\x18\x10 \x01(\x0b\x32\x14.CbProcessBlockedMsg\x12\"\n\x04\x65met\x18\x11 \x01(\x0b\x32\x14.CbEmetMitigationMsg\x12,\n\x0enetconnBlocked\x18\x12 \x01(\x0b\x32\x14.CbNetConnBlockedMsg\x12*\n\x0bprocessMeta\x18\x13 \x01(\x0b\x32\x15.CbProcessMetadataMsg')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CBSTRINGMSG_CBSTRINGTYPE = _descriptor.EnumDescriptor(
  name='CbStringType',
  full_name='CbStringMsg.CbStringType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='typeFilepath', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='typeRegpath', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='typeNetpath', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=436,
  serialized_end=502,
)
_sym_db.RegisterEnumDescriptor(_CBSTRINGMSG_CBSTRINGTYPE)

_CBSUPPRESSEDINFO_CBSUPPRESSEDPROCESSSTATE = _descriptor.EnumDescriptor(
  name='CbSuppressedProcessState',
  full_name='CbSuppressedInfo.CbSuppressedProcessState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='suppressedEventlessModloads', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='suppressedEventlessWithXproc', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1069,
  serialized_end=1162,
)
_sym_db.RegisterEnumDescriptor(_CBSUPPRESSEDINFO_CBSUPPRESSEDPROCESSSTATE)

_CBCHILDPROCESSMSG_CBCHILDPROCTYPE = _descriptor.EnumDescriptor(
  name='CbChildProcType',
  full_name='CbChildProcessMsg.CbChildProcType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='childProcExec', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='childProcFork', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='childProcOtherExec', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1484,
  serialized_end=1563,
)
_sym_db.RegisterEnumDescriptor(_CBCHILDPROCESSMSG_CBCHILDPROCTYPE)

_CBFILEMODMSG_CBFILEMODACTION = _descriptor.EnumDescriptor(
  name='CbFileModAction',
  full_name='CbFileModMsg.CbFileModAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='actionFileModCreate', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionFileModWrite', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionFileModDelete', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionFileModLastWrite', index=3, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionFileModOpen', index=4, number=16,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1921,
  serialized_end=2063,
)
_sym_db.RegisterEnumDescriptor(_CBFILEMODMSG_CBFILEMODACTION)

_CBFILEMODMSG_CBFILETYPE = _descriptor.EnumDescriptor(
  name='CbFileType',
  full_name='CbFileModMsg.CbFileType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='filetypeUnknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypePe', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeElf', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeUniversalBin', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeEicar', index=4, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeOfficeLegacy', index=5, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeOfficeOpenXml', index=6, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypePdf', index=7, number=48,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeArchivePkzip', index=8, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeArchiveLzh', index=9, number=65,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeArchiveLzw', index=10, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeArchiveRar', index=11, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeArchiveTar', index=12, number=68,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filetypeArchive7zip', index=13, number=69,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2066,
  serialized_end=2394,
)
_sym_db.RegisterEnumDescriptor(_CBFILEMODMSG_CBFILETYPE)

_CBREGMODMSG_CBREGMODACTION = _descriptor.EnumDescriptor(
  name='CbRegModAction',
  full_name='CbRegModMsg.CbRegModAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='actionRegModCreateKey', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionRegModWriteValue', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionRegModDeleteKey', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionRegModDeleteValue', index=3, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2542,
  serialized_end=2669,
)
_sym_db.RegisterEnumDescriptor(_CBREGMODMSG_CBREGMODACTION)

_CBNETCONNMSG_PROTOCOLTYPE = _descriptor.EnumDescriptor(
  name='ProtocolType',
  full_name='CbNetConnMsg.ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ProtoTcp', index=0, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ProtoUdp', index=1, number=17,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3056,
  serialized_end=3098,
)
_sym_db.RegisterEnumDescriptor(_CBNETCONNMSG_PROTOCOLTYPE)

_CBCROSSPROCESSOPENMSG_OPENTYPE = _descriptor.EnumDescriptor(
  name='OpenType',
  full_name='CbCrossProcessOpenMsg.OpenType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OpenProcessHandle', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OpenThreadHandle', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3531,
  serialized_end=3586,
)
_sym_db.RegisterEnumDescriptor(_CBCROSSPROCESSOPENMSG_OPENTYPE)

_CBPROCESSBLOCKEDMSG_BLOCKTYPE = _descriptor.EnumDescriptor(
  name='BlockType',
  full_name='CbProcessBlockedMsg.BlockType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MD5Hash', index=0, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4229,
  serialized_end=4253,
)
_sym_db.RegisterEnumDescriptor(_CBPROCESSBLOCKEDMSG_BLOCKTYPE)

_CBPROCESSBLOCKEDMSG_BLOCKEVENT = _descriptor.EnumDescriptor(
  name='BlockEvent',
  full_name='CbProcessBlockedMsg.BlockEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ProcessCreate', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RunningProcess', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4255,
  serialized_end=4306,
)
_sym_db.RegisterEnumDescriptor(_CBPROCESSBLOCKEDMSG_BLOCKEVENT)

_CBPROCESSBLOCKEDMSG_BLOCKRESULT = _descriptor.EnumDescriptor(
  name='BlockResult',
  full_name='CbProcessBlockedMsg.BlockResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ProcessTerminated', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotTerminatedCBProcess', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotTerminatedSystemProcess', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotTerminatedCriticalSystemProcess', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotTerminatedWhitelistedPath', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotTerminatedOpenProcessError', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotTerminatedTerminateError', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4309,
  serialized_end=4547,
)
_sym_db.RegisterEnumDescriptor(_CBPROCESSBLOCKEDMSG_BLOCKRESULT)

_CBNETCONNBLOCKEDMSG_NETCONNBLOCKTYPE = _descriptor.EnumDescriptor(
  name='NetconnBlockType',
  full_name='CbNetConnBlockedMsg.NetconnBlockType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NetworkIsolation', index=0, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4994,
  serialized_end=5034,
)
_sym_db.RegisterEnumDescriptor(_CBNETCONNBLOCKEDMSG_NETCONNBLOCKTYPE)

_CBNETCONNBLOCKEDMSG_PROTOCOLTYPE = _descriptor.EnumDescriptor(
  name='ProtocolType',
  full_name='CbNetConnBlockedMsg.ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ProtoTcp', index=0, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ProtoUdp', index=1, number=17,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3056,
  serialized_end=3098,
)
_sym_db.RegisterEnumDescriptor(_CBNETCONNBLOCKEDMSG_PROTOCOLTYPE)

_CBTAMPERALERTMSG_CBTAMPERALERTTYPE = _descriptor.EnumDescriptor(
  name='CbTamperAlertType',
  full_name='CbTamperAlertMsg.CbTamperAlertType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AlertCoreDriverUnloaded', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AlertNetworkDriverUnloaded', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AlertCbServiceStopped', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AlertCbProcessTerminated', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AlertCbCodeInjection', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6418,
  serialized_end=6581,
)
_sym_db.RegisterEnumDescriptor(_CBTAMPERALERTMSG_CBTAMPERALERTTYPE)

_CBEMETMITIGATIONACTION_CBEMETMITIGATIONTYPES = _descriptor.EnumDescriptor(
  name='CbEmetMitigationTypes',
  full_name='CbEmetMitigationAction.CbEmetMitigationTypes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='actionDep', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionSehop', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionAsr', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionAslr', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionNullPage', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionHeapSpray', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionMandatoryAslr', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionEaf', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionEafPlus', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionBottomUpAslr', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionLoadLibrary', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionMemoryProtection', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionSimulateExecFlow', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionStackPivot', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionCallerChecks', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionBannedFunctions', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionDeepHooks', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='actionAntiDetours', index=17, number=18,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6682,
  serialized_end=7088,
)
_sym_db.RegisterEnumDescriptor(_CBEMETMITIGATIONACTION_CBEMETMITIGATIONTYPES)


_CBHEADERMSG = _descriptor.Descriptor(
  name='CbHeaderMsg',
  full_name='CbHeaderMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CbHeaderMsg.version', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootid', full_name='CbHeaderMsg.bootid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eventid', full_name='CbHeaderMsg.eventid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CbHeaderMsg.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_guid', full_name='CbHeaderMsg.process_guid', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filepath_string_guid', full_name='CbHeaderMsg.filepath_string_guid', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='magic', full_name='CbHeaderMsg.magic', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_filepath_string_guid', full_name='CbHeaderMsg.process_filepath_string_guid', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_create_time', full_name='CbHeaderMsg.process_create_time', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_pid', full_name='CbHeaderMsg.process_pid', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_md5', full_name='CbHeaderMsg.process_md5', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_path', full_name='CbHeaderMsg.process_path', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fork_pid', full_name='CbHeaderMsg.fork_pid', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=322,
)


_CBSTRINGMSG = _descriptor.Descriptor(
  name='CbStringMsg',
  full_name='CbStringMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guid', full_name='CbStringMsg.guid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8string', full_name='CbStringMsg.utf8string', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_type', full_name='CbStringMsg.string_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBSTRINGMSG_CBSTRINGTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=502,
)


_CBPROCESSMSG = _descriptor.Descriptor(
  name='CbProcessMsg',
  full_name='CbProcessMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='CbProcessMsg.pid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created', full_name='CbProcessMsg.created', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_pid', full_name='CbProcessMsg.parent_pid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_create_time', full_name='CbProcessMsg.parent_create_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_guid', full_name='CbProcessMsg.parent_guid', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5hash', full_name='CbProcessMsg.md5hash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='have_seen_before', full_name='CbProcessMsg.have_seen_before', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='CbProcessMsg.deprecated', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commandline', full_name='CbProcessMsg.commandline', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_md5', full_name='CbProcessMsg.parent_md5', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_path', full_name='CbProcessMsg.parent_path', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creationobserved', full_name='CbProcessMsg.creationobserved', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expect_followon_w_md5', full_name='CbProcessMsg.expect_followon_w_md5', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='CbProcessMsg.uid', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CbProcessMsg.username', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actions', full_name='CbProcessMsg.actions', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actionsAreFromGPO', full_name='CbProcessMsg.actionsAreFromGPO', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bFilteringKnownDlls', full_name='CbProcessMsg.bFilteringKnownDlls', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=957,
)


_CBSUPPRESSEDINFO = _descriptor.Descriptor(
  name='CbSuppressedInfo',
  full_name='CbSuppressedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bIsSuppressed', full_name='CbSuppressedInfo.bIsSuppressed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CbSuppressedInfo.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBSUPPRESSEDINFO_CBSUPPRESSEDPROCESSSTATE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1162,
)


_CBCHILDPROCESSMSG = _descriptor.Descriptor(
  name='CbChildProcessMsg',
  full_name='CbChildProcessMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='created', full_name='CbChildProcessMsg.created', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_guid', full_name='CbChildProcessMsg.parent_guid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5hash', full_name='CbChildProcessMsg.md5hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='child_guid', full_name='CbChildProcessMsg.child_guid', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='CbChildProcessMsg.path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='CbChildProcessMsg.pid', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='CbChildProcessMsg.create_time', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tamper', full_name='CbChildProcessMsg.tamper', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suppressed', full_name='CbChildProcessMsg.suppressed', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commandline', full_name='CbChildProcessMsg.commandline', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CbChildProcessMsg.username', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='childProcType', full_name='CbChildProcessMsg.childProcType', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBCHILDPROCESSMSG_CBCHILDPROCTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1563,
)


_CBMODULELOADMSG = _descriptor.Descriptor(
  name='CbModuleLoadMsg',
  full_name='CbModuleLoadMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guid', full_name='CbModuleLoadMsg.guid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handlepath_string_guid', full_name='CbModuleLoadMsg.handlepath_string_guid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5hash', full_name='CbModuleLoadMsg.md5hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scanid', full_name='CbModuleLoadMsg.scanid', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_process_base_module', full_name='CbModuleLoadMsg.is_process_base_module', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_base', full_name='CbModuleLoadMsg.image_base', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_size', full_name='CbModuleLoadMsg.image_size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1566,
  serialized_end=1734,
)


_CBFILEMODMSG = _descriptor.Descriptor(
  name='CbFileModMsg',
  full_name='CbFileModMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guid', full_name='CbFileModMsg.guid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='CbFileModMsg.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='have_seen_before', full_name='CbFileModMsg.have_seen_before', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5hash', full_name='CbFileModMsg.md5hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CbFileModMsg.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tamper', full_name='CbFileModMsg.tamper', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBFILEMODMSG_CBFILEMODACTION,
    _CBFILEMODMSG_CBFILETYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=2394,
)


_CBREGMODMSG = _descriptor.Descriptor(
  name='CbRegModMsg',
  full_name='CbRegModMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guid', full_name='CbRegModMsg.guid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='CbRegModMsg.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='have_seen_before', full_name='CbRegModMsg.have_seen_before', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_regpath', full_name='CbRegModMsg.utf8_regpath', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tamper', full_name='CbRegModMsg.tamper', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBREGMODMSG_CBREGMODACTION,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2397,
  serialized_end=2669,
)


_CBNETCONNMSG = _descriptor.Descriptor(
  name='CbNetConnMsg',
  full_name='CbNetConnMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guid', full_name='CbNetConnMsg.guid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv4Address', full_name='CbNetConnMsg.ipv4Address', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv6LoPart', full_name='CbNetConnMsg.ipv6LoPart', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv6HiPart', full_name='CbNetConnMsg.ipv6HiPart', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='CbNetConnMsg.port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='CbNetConnMsg.protocol', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=6,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_netpath', full_name='CbNetConnMsg.utf8_netpath', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outbound', full_name='CbNetConnMsg.outbound', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyConnection', full_name='CbNetConnMsg.proxyConnection', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyIpv4Address', full_name='CbNetConnMsg.proxyIpv4Address', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyPort', full_name='CbNetConnMsg.proxyPort', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyNetPath', full_name='CbNetConnMsg.proxyNetPath', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remoteIpAddress', full_name='CbNetConnMsg.remoteIpAddress', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remotePort', full_name='CbNetConnMsg.remotePort', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='localIpAddress', full_name='CbNetConnMsg.localIpAddress', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='localPort', full_name='CbNetConnMsg.localPort', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBNETCONNMSG_PROTOCOLTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2672,
  serialized_end=3098,
)


_CBLINSTATSMSG = _descriptor.Descriptor(
  name='CbLinStatsMsg',
  full_name='CbLinStatsMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lin_total', full_name='CbLinStatsMsg.lin_total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lin_successful', full_name='CbLinStatsMsg.lin_successful', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lin_no_scanidi', full_name='CbLinStatsMsg.lin_no_scanidi', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lin_total_pended', full_name='CbLinStatsMsg.lin_total_pended', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lin_current_scanid_pended_size', full_name='CbLinStatsMsg.lin_current_scanid_pended_size', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lin_current_handlepath_pended_size', full_name='CbLinStatsMsg.lin_current_handlepath_pended_size', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lin_current_filepath_pended_size', full_name='CbLinStatsMsg.lin_current_filepath_pended_size', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3101,
  serialized_end=3335,
)


_CBCROSSPROCESSOPENMSG = _descriptor.Descriptor(
  name='CbCrossProcessOpenMsg',
  full_name='CbCrossProcessOpenMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CbCrossProcessOpenMsg.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetPid', full_name='CbCrossProcessOpenMsg.targetPid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetProcCreateTime', full_name='CbCrossProcessOpenMsg.targetProcCreateTime', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requestedAccess', full_name='CbCrossProcessOpenMsg.requestedAccess', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetProcPath', full_name='CbCrossProcessOpenMsg.targetProcPath', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetProcMd5', full_name='CbCrossProcessOpenMsg.targetProcMd5', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBCROSSPROCESSOPENMSG_OPENTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3338,
  serialized_end=3586,
)


_CBCREATEREMOTETHREADMSG = _descriptor.Descriptor(
  name='CbCreateRemoteThreadMsg',
  full_name='CbCreateRemoteThreadMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='remoteProcPid', full_name='CbCreateRemoteThreadMsg.remoteProcPid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remoteProcCreateTime', full_name='CbCreateRemoteThreadMsg.remoteProcCreateTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remoteProcPath', full_name='CbCreateRemoteThreadMsg.remoteProcPath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remoteProcMd5', full_name='CbCreateRemoteThreadMsg.remoteProcMd5', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3588,
  serialized_end=3713,
)


_CBCROSSPROCESSMSG = _descriptor.Descriptor(
  name='CbCrossProcessMsg',
  full_name='CbCrossProcessMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='open', full_name='CbCrossProcessMsg.open', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remotethread', full_name='CbCrossProcessMsg.remotethread', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tamper', full_name='CbCrossProcessMsg.tamper', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isTarget', full_name='CbCrossProcessMsg.isTarget', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3716,
  serialized_end=3855,
)


_CBPROCESSBLOCKEDMSG = _descriptor.Descriptor(
  name='CbProcessBlockedMsg',
  full_name='CbProcessBlockedMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockedType', full_name='CbProcessBlockedMsg.blockedType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedEvent', full_name='CbProcessBlockedMsg.blockedEvent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedmd5Hash', full_name='CbProcessBlockedMsg.blockedmd5Hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedPath', full_name='CbProcessBlockedMsg.blockedPath', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockResult', full_name='CbProcessBlockedMsg.blockResult', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockError', full_name='CbProcessBlockedMsg.blockError', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedPid', full_name='CbProcessBlockedMsg.blockedPid', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedProcCreateTime', full_name='CbProcessBlockedMsg.blockedProcCreateTime', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedCmdline', full_name='CbProcessBlockedMsg.blockedCmdline', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedUid', full_name='CbProcessBlockedMsg.blockedUid', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockedUsername', full_name='CbProcessBlockedMsg.blockedUsername', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBPROCESSBLOCKEDMSG_BLOCKTYPE,
    _CBPROCESSBLOCKEDMSG_BLOCKEVENT,
    _CBPROCESSBLOCKEDMSG_BLOCKRESULT,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3858,
  serialized_end=4547,
)


_CBNETCONNBLOCKEDMSG = _descriptor.Descriptor(
  name='CbNetConnBlockedMsg',
  full_name='CbNetConnBlockedMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockedType', full_name='CbNetConnBlockedMsg.blockedType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv4Address', full_name='CbNetConnBlockedMsg.ipv4Address', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv6LoPart', full_name='CbNetConnBlockedMsg.ipv6LoPart', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv6HiPart', full_name='CbNetConnBlockedMsg.ipv6HiPart', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='CbNetConnBlockedMsg.port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='CbNetConnBlockedMsg.protocol', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=6,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_netpath', full_name='CbNetConnBlockedMsg.utf8_netpath', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outbound', full_name='CbNetConnBlockedMsg.outbound', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyConnection', full_name='CbNetConnBlockedMsg.proxyConnection', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyIpv4Address', full_name='CbNetConnBlockedMsg.proxyIpv4Address', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyPort', full_name='CbNetConnBlockedMsg.proxyPort', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxyNetPath', full_name='CbNetConnBlockedMsg.proxyNetPath', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remoteIpAddress', full_name='CbNetConnBlockedMsg.remoteIpAddress', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remotePort', full_name='CbNetConnBlockedMsg.remotePort', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='localIpAddress', full_name='CbNetConnBlockedMsg.localIpAddress', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='localPort', full_name='CbNetConnBlockedMsg.localPort', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBNETCONNBLOCKEDMSG_NETCONNBLOCKTYPE,
    _CBNETCONNBLOCKEDMSG_PROTOCOLTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4550,
  serialized_end=5078,
)


_CBSTATISTICSMSG = _descriptor.Descriptor(
  name='CbStatisticsMsg',
  full_name='CbStatisticsMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lin_stats', full_name='CbStatisticsMsg.lin_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5080,
  serialized_end=5132,
)


_CBMODULEINFOMSG = _descriptor.Descriptor(
  name='CbModuleInfoMsg',
  full_name='CbModuleInfoMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='md5', full_name='CbModuleInfoMsg.md5', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CopiedModuleLength', full_name='CbModuleInfoMsg.CopiedModuleLength', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='OriginalModuleLength', full_name='CbModuleInfoMsg.OriginalModuleLength', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_FileDescription', full_name='CbModuleInfoMsg.utf8_FileDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_CompanyName', full_name='CbModuleInfoMsg.utf8_CompanyName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_ProductName', full_name='CbModuleInfoMsg.utf8_ProductName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_FileVersion', full_name='CbModuleInfoMsg.utf8_FileVersion', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_Comments', full_name='CbModuleInfoMsg.utf8_Comments', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_LegalCopyright', full_name='CbModuleInfoMsg.utf8_LegalCopyright', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_LegalTrademark', full_name='CbModuleInfoMsg.utf8_LegalTrademark', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_InternalName', full_name='CbModuleInfoMsg.utf8_InternalName', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_OriginalFileName', full_name='CbModuleInfoMsg.utf8_OriginalFileName', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_ProductDescription', full_name='CbModuleInfoMsg.utf8_ProductDescription', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_ProductVersion', full_name='CbModuleInfoMsg.utf8_ProductVersion', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_PrivateBuild', full_name='CbModuleInfoMsg.utf8_PrivateBuild', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_SpecialBuild', full_name='CbModuleInfoMsg.utf8_SpecialBuild', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_Publisher', full_name='CbModuleInfoMsg.utf8_DigSig_Publisher', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_ProgramName', full_name='CbModuleInfoMsg.utf8_DigSig_ProgramName', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_IssuerName', full_name='CbModuleInfoMsg.utf8_DigSig_IssuerName', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_SubjectName', full_name='CbModuleInfoMsg.utf8_DigSig_SubjectName', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_Result', full_name='CbModuleInfoMsg.utf8_DigSig_Result', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_ResultCode', full_name='CbModuleInfoMsg.utf8_DigSig_ResultCode', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_DigSig_SignTime', full_name='CbModuleInfoMsg.utf8_DigSig_SignTime', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Icon', full_name='CbModuleInfoMsg.Icon', index=23,
      number=24, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ImageFileHeader', full_name='CbModuleInfoMsg.ImageFileHeader', index=24,
      number=25, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utf8_OnDiskFilename', full_name='CbModuleInfoMsg.utf8_OnDiskFilename', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5135,
  serialized_end=5873,
)


_CBVTWRITEMSG = _descriptor.Descriptor(
  name='CbVtWriteMsg',
  full_name='CbVtWriteMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='WritingProcessExeMd5', full_name='CbVtWriteMsg.WritingProcessExeMd5', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='FileWrittenMd5', full_name='CbVtWriteMsg.FileWrittenMd5', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='FileWrittenIsPeModuleHint', full_name='CbVtWriteMsg.FileWrittenIsPeModuleHint', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='WritingProcessFilename', full_name='CbVtWriteMsg.WritingProcessFilename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='FileWrittenFilename', full_name='CbVtWriteMsg.FileWrittenFilename', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5876,
  serialized_end=6040,
)


_CBVTLOADMSG = _descriptor.Descriptor(
  name='CbVtLoadMsg',
  full_name='CbVtLoadMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='LoaderProcessExeMd5', full_name='CbVtLoadMsg.LoaderProcessExeMd5', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='LoadedModuleMd5', full_name='CbVtLoadMsg.LoadedModuleMd5', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6042,
  serialized_end=6109,
)


_CBENDPOINTENVIRONMENTMSG = _descriptor.Descriptor(
  name='CbEndpointEnvironmentMsg',
  full_name='CbEndpointEnvironmentMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='SensorId', full_name='CbEndpointEnvironmentMsg.SensorId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='SensorHostName', full_name='CbEndpointEnvironmentMsg.SensorHostName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='HostId', full_name='CbEndpointEnvironmentMsg.HostId', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6111,
  serialized_end=6195,
)


_CBSERVERENVIRONMENTMSG = _descriptor.Descriptor(
  name='CbServerEnvironmentMsg',
  full_name='CbServerEnvironmentMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='NodeId', full_name='CbServerEnvironmentMsg.NodeId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6197,
  serialized_end=6237,
)


_CBENVIRONMENTMSG = _descriptor.Descriptor(
  name='CbEnvironmentMsg',
  full_name='CbEnvironmentMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='CbEnvironmentMsg.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server', full_name='CbEnvironmentMsg.server', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6239,
  serialized_end=6343,
)


_CBTAMPERALERTMSG = _descriptor.Descriptor(
  name='CbTamperAlertMsg',
  full_name='CbTamperAlertMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CbTamperAlertMsg.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBTAMPERALERTMSG_CBTAMPERALERTTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6346,
  serialized_end=6581,
)


_CBEMETMITIGATIONACTION = _descriptor.Descriptor(
  name='CbEmetMitigationAction',
  full_name='CbEmetMitigationAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mitigationType', full_name='CbEmetMitigationAction.mitigationType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBEMETMITIGATIONACTION_CBEMETMITIGATIONTYPES,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6584,
  serialized_end=7088,
)


_CBEMETMITIGATIONMSG = _descriptor.Descriptor(
  name='CbEmetMitigationMsg',
  full_name='CbEmetMitigationMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='emetId', full_name='CbEmetMitigationMsg.emetId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emetTimstamp', full_name='CbEmetMitigationMsg.emetTimstamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='CbEmetMitigationMsg.action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actionText', full_name='CbEmetMitigationMsg.actionText', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blocked', full_name='CbEmetMitigationMsg.blocked', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7091,
  serialized_end=7235,
)


_CBPROCESSMETADATAMSG = _descriptor.Descriptor(
  name='CbProcessMetadataMsg',
  full_name='CbProcessMetadataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='process_guid', full_name='CbProcessMetadataMsg.process_guid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_create_time', full_name='CbProcessMetadataMsg.process_create_time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_pid', full_name='CbProcessMetadataMsg.process_pid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_md5', full_name='CbProcessMetadataMsg.process_md5', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_path', full_name='CbProcessMetadataMsg.process_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='CbProcessMetadataMsg.uid', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CbProcessMetadataMsg.username', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commandline', full_name='CbProcessMetadataMsg.commandline', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_pid', full_name='CbProcessMetadataMsg.parent_pid', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_create_time', full_name='CbProcessMetadataMsg.parent_create_time', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_md5', full_name='CbProcessMetadataMsg.parent_md5', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_path', full_name='CbProcessMetadataMsg.parent_path', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modload_count', full_name='CbProcessMetadataMsg.modload_count', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filemod_count', full_name='CbProcessMetadataMsg.filemod_count', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='netconn_count', full_name='CbProcessMetadataMsg.netconn_count', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='regmod_count', full_name='CbProcessMetadataMsg.regmod_count', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='childproc_count', full_name='CbProcessMetadataMsg.childproc_count', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crossproc_count', full_name='CbProcessMetadataMsg.crossproc_count', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emet_count', full_name='CbProcessMetadataMsg.emet_count', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='processblock_count', full_name='CbProcessMetadataMsg.processblock_count', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sensor_start_time', full_name='CbProcessMetadataMsg.sensor_start_time', index=20,
      number=21, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sensor_segment', full_name='CbProcessMetadataMsg.sensor_segment', index=21,
      number=22, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creationobserved', full_name='CbProcessMetadataMsg.creationobserved', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7238,
  serialized_end=7789,
)


_CBEVENTMSG = _descriptor.Descriptor(
  name='CbEventMsg',
  full_name='CbEventMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='CbEventMsg.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strings', full_name='CbEventMsg.strings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process', full_name='CbEventMsg.process', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modload', full_name='CbEventMsg.modload', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filemod', full_name='CbEventMsg.filemod', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network', full_name='CbEventMsg.network', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='regmod', full_name='CbEventMsg.regmod', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CbEventMsg.stats', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='module', full_name='CbEventMsg.module', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vtwrite', full_name='CbEventMsg.vtwrite', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vtload', full_name='CbEventMsg.vtload', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='childproc', full_name='CbEventMsg.childproc', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='env', full_name='CbEventMsg.env', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crossproc', full_name='CbEventMsg.crossproc', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tamperAlert', full_name='CbEventMsg.tamperAlert', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blocked', full_name='CbEventMsg.blocked', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emet', full_name='CbEventMsg.emet', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='netconnBlocked', full_name='CbEventMsg.netconnBlocked', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='processMeta', full_name='CbEventMsg.processMeta', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7792,
  serialized_end=8470,
)

_CBSTRINGMSG.fields_by_name['string_type'].enum_type = _CBSTRINGMSG_CBSTRINGTYPE
_CBSTRINGMSG_CBSTRINGTYPE.containing_type = _CBSTRINGMSG
_CBPROCESSMSG.fields_by_name['actions'].message_type = _CBEMETMITIGATIONACTION
_CBSUPPRESSEDINFO.fields_by_name['state'].enum_type = _CBSUPPRESSEDINFO_CBSUPPRESSEDPROCESSSTATE
_CBSUPPRESSEDINFO_CBSUPPRESSEDPROCESSSTATE.containing_type = _CBSUPPRESSEDINFO
_CBCHILDPROCESSMSG.fields_by_name['suppressed'].message_type = _CBSUPPRESSEDINFO
_CBCHILDPROCESSMSG.fields_by_name['childProcType'].enum_type = _CBCHILDPROCESSMSG_CBCHILDPROCTYPE
_CBCHILDPROCESSMSG_CBCHILDPROCTYPE.containing_type = _CBCHILDPROCESSMSG
_CBFILEMODMSG.fields_by_name['action'].enum_type = _CBFILEMODMSG_CBFILEMODACTION
_CBFILEMODMSG.fields_by_name['type'].enum_type = _CBFILEMODMSG_CBFILETYPE
_CBFILEMODMSG_CBFILEMODACTION.containing_type = _CBFILEMODMSG
_CBFILEMODMSG_CBFILETYPE.containing_type = _CBFILEMODMSG
_CBREGMODMSG.fields_by_name['action'].enum_type = _CBREGMODMSG_CBREGMODACTION
_CBREGMODMSG_CBREGMODACTION.containing_type = _CBREGMODMSG
_CBNETCONNMSG.fields_by_name['protocol'].enum_type = _CBNETCONNMSG_PROTOCOLTYPE
_CBNETCONNMSG_PROTOCOLTYPE.containing_type = _CBNETCONNMSG
_CBCROSSPROCESSOPENMSG.fields_by_name['type'].enum_type = _CBCROSSPROCESSOPENMSG_OPENTYPE
_CBCROSSPROCESSOPENMSG_OPENTYPE.containing_type = _CBCROSSPROCESSOPENMSG
_CBCROSSPROCESSMSG.fields_by_name['open'].message_type = _CBCROSSPROCESSOPENMSG
_CBCROSSPROCESSMSG.fields_by_name['remotethread'].message_type = _CBCREATEREMOTETHREADMSG
_CBPROCESSBLOCKEDMSG.fields_by_name['blockedType'].enum_type = _CBPROCESSBLOCKEDMSG_BLOCKTYPE
_CBPROCESSBLOCKEDMSG.fields_by_name['blockedEvent'].enum_type = _CBPROCESSBLOCKEDMSG_BLOCKEVENT
_CBPROCESSBLOCKEDMSG.fields_by_name['blockResult'].enum_type = _CBPROCESSBLOCKEDMSG_BLOCKRESULT
_CBPROCESSBLOCKEDMSG_BLOCKTYPE.containing_type = _CBPROCESSBLOCKEDMSG
_CBPROCESSBLOCKEDMSG_BLOCKEVENT.containing_type = _CBPROCESSBLOCKEDMSG
_CBPROCESSBLOCKEDMSG_BLOCKRESULT.containing_type = _CBPROCESSBLOCKEDMSG
_CBNETCONNBLOCKEDMSG.fields_by_name['blockedType'].enum_type = _CBNETCONNBLOCKEDMSG_NETCONNBLOCKTYPE
_CBNETCONNBLOCKEDMSG.fields_by_name['protocol'].enum_type = _CBNETCONNBLOCKEDMSG_PROTOCOLTYPE
_CBNETCONNBLOCKEDMSG_NETCONNBLOCKTYPE.containing_type = _CBNETCONNBLOCKEDMSG
_CBNETCONNBLOCKEDMSG_PROTOCOLTYPE.containing_type = _CBNETCONNBLOCKEDMSG
_CBSTATISTICSMSG.fields_by_name['lin_stats'].message_type = _CBLINSTATSMSG
_CBENVIRONMENTMSG.fields_by_name['endpoint'].message_type = _CBENDPOINTENVIRONMENTMSG
_CBENVIRONMENTMSG.fields_by_name['server'].message_type = _CBSERVERENVIRONMENTMSG
_CBTAMPERALERTMSG.fields_by_name['type'].enum_type = _CBTAMPERALERTMSG_CBTAMPERALERTTYPE
_CBTAMPERALERTMSG_CBTAMPERALERTTYPE.containing_type = _CBTAMPERALERTMSG
_CBEMETMITIGATIONACTION.fields_by_name['mitigationType'].enum_type = _CBEMETMITIGATIONACTION_CBEMETMITIGATIONTYPES
_CBEMETMITIGATIONACTION_CBEMETMITIGATIONTYPES.containing_type = _CBEMETMITIGATIONACTION
_CBEMETMITIGATIONMSG.fields_by_name['action'].message_type = _CBEMETMITIGATIONACTION
_CBEVENTMSG.fields_by_name['header'].message_type = _CBHEADERMSG
_CBEVENTMSG.fields_by_name['strings'].message_type = _CBSTRINGMSG
_CBEVENTMSG.fields_by_name['process'].message_type = _CBPROCESSMSG
_CBEVENTMSG.fields_by_name['modload'].message_type = _CBMODULELOADMSG
_CBEVENTMSG.fields_by_name['filemod'].message_type = _CBFILEMODMSG
_CBEVENTMSG.fields_by_name['network'].message_type = _CBNETCONNMSG
_CBEVENTMSG.fields_by_name['regmod'].message_type = _CBREGMODMSG
_CBEVENTMSG.fields_by_name['stats'].message_type = _CBSTATISTICSMSG
_CBEVENTMSG.fields_by_name['module'].message_type = _CBMODULEINFOMSG
_CBEVENTMSG.fields_by_name['vtwrite'].message_type = _CBVTWRITEMSG
_CBEVENTMSG.fields_by_name['vtload'].message_type = _CBVTLOADMSG
_CBEVENTMSG.fields_by_name['childproc'].message_type = _CBCHILDPROCESSMSG
_CBEVENTMSG.fields_by_name['env'].message_type = _CBENVIRONMENTMSG
_CBEVENTMSG.fields_by_name['crossproc'].message_type = _CBCROSSPROCESSMSG
_CBEVENTMSG.fields_by_name['tamperAlert'].message_type = _CBTAMPERALERTMSG
_CBEVENTMSG.fields_by_name['blocked'].message_type = _CBPROCESSBLOCKEDMSG
_CBEVENTMSG.fields_by_name['emet'].message_type = _CBEMETMITIGATIONMSG
_CBEVENTMSG.fields_by_name['netconnBlocked'].message_type = _CBNETCONNBLOCKEDMSG
_CBEVENTMSG.fields_by_name['processMeta'].message_type = _CBPROCESSMETADATAMSG
DESCRIPTOR.message_types_by_name['CbHeaderMsg'] = _CBHEADERMSG
DESCRIPTOR.message_types_by_name['CbStringMsg'] = _CBSTRINGMSG
DESCRIPTOR.message_types_by_name['CbProcessMsg'] = _CBPROCESSMSG
DESCRIPTOR.message_types_by_name['CbSuppressedInfo'] = _CBSUPPRESSEDINFO
DESCRIPTOR.message_types_by_name['CbChildProcessMsg'] = _CBCHILDPROCESSMSG
DESCRIPTOR.message_types_by_name['CbModuleLoadMsg'] = _CBMODULELOADMSG
DESCRIPTOR.message_types_by_name['CbFileModMsg'] = _CBFILEMODMSG
DESCRIPTOR.message_types_by_name['CbRegModMsg'] = _CBREGMODMSG
DESCRIPTOR.message_types_by_name['CbNetConnMsg'] = _CBNETCONNMSG
DESCRIPTOR.message_types_by_name['CbLinStatsMsg'] = _CBLINSTATSMSG
DESCRIPTOR.message_types_by_name['CbCrossProcessOpenMsg'] = _CBCROSSPROCESSOPENMSG
DESCRIPTOR.message_types_by_name['CbCreateRemoteThreadMsg'] = _CBCREATEREMOTETHREADMSG
DESCRIPTOR.message_types_by_name['CbCrossProcessMsg'] = _CBCROSSPROCESSMSG
DESCRIPTOR.message_types_by_name['CbProcessBlockedMsg'] = _CBPROCESSBLOCKEDMSG
DESCRIPTOR.message_types_by_name['CbNetConnBlockedMsg'] = _CBNETCONNBLOCKEDMSG
DESCRIPTOR.message_types_by_name['CbStatisticsMsg'] = _CBSTATISTICSMSG
DESCRIPTOR.message_types_by_name['CbModuleInfoMsg'] = _CBMODULEINFOMSG
DESCRIPTOR.message_types_by_name['CbVtWriteMsg'] = _CBVTWRITEMSG
DESCRIPTOR.message_types_by_name['CbVtLoadMsg'] = _CBVTLOADMSG
DESCRIPTOR.message_types_by_name['CbEndpointEnvironmentMsg'] = _CBENDPOINTENVIRONMENTMSG
DESCRIPTOR.message_types_by_name['CbServerEnvironmentMsg'] = _CBSERVERENVIRONMENTMSG
DESCRIPTOR.message_types_by_name['CbEnvironmentMsg'] = _CBENVIRONMENTMSG
DESCRIPTOR.message_types_by_name['CbTamperAlertMsg'] = _CBTAMPERALERTMSG
DESCRIPTOR.message_types_by_name['CbEmetMitigationAction'] = _CBEMETMITIGATIONACTION
DESCRIPTOR.message_types_by_name['CbEmetMitigationMsg'] = _CBEMETMITIGATIONMSG
DESCRIPTOR.message_types_by_name['CbProcessMetadataMsg'] = _CBPROCESSMETADATAMSG
DESCRIPTOR.message_types_by_name['CbEventMsg'] = _CBEVENTMSG

CbHeaderMsg = _reflection.GeneratedProtocolMessageType('CbHeaderMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBHEADERMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbHeaderMsg)
  ))
_sym_db.RegisterMessage(CbHeaderMsg)

CbStringMsg = _reflection.GeneratedProtocolMessageType('CbStringMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBSTRINGMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbStringMsg)
  ))
_sym_db.RegisterMessage(CbStringMsg)

CbProcessMsg = _reflection.GeneratedProtocolMessageType('CbProcessMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBPROCESSMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbProcessMsg)
  ))
_sym_db.RegisterMessage(CbProcessMsg)

CbSuppressedInfo = _reflection.GeneratedProtocolMessageType('CbSuppressedInfo', (_message.Message,), dict(
  DESCRIPTOR = _CBSUPPRESSEDINFO,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbSuppressedInfo)
  ))
_sym_db.RegisterMessage(CbSuppressedInfo)

CbChildProcessMsg = _reflection.GeneratedProtocolMessageType('CbChildProcessMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBCHILDPROCESSMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbChildProcessMsg)
  ))
_sym_db.RegisterMessage(CbChildProcessMsg)

CbModuleLoadMsg = _reflection.GeneratedProtocolMessageType('CbModuleLoadMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBMODULELOADMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbModuleLoadMsg)
  ))
_sym_db.RegisterMessage(CbModuleLoadMsg)

CbFileModMsg = _reflection.GeneratedProtocolMessageType('CbFileModMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBFILEMODMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbFileModMsg)
  ))
_sym_db.RegisterMessage(CbFileModMsg)

CbRegModMsg = _reflection.GeneratedProtocolMessageType('CbRegModMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBREGMODMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbRegModMsg)
  ))
_sym_db.RegisterMessage(CbRegModMsg)

CbNetConnMsg = _reflection.GeneratedProtocolMessageType('CbNetConnMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBNETCONNMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbNetConnMsg)
  ))
_sym_db.RegisterMessage(CbNetConnMsg)

CbLinStatsMsg = _reflection.GeneratedProtocolMessageType('CbLinStatsMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBLINSTATSMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbLinStatsMsg)
  ))
_sym_db.RegisterMessage(CbLinStatsMsg)

CbCrossProcessOpenMsg = _reflection.GeneratedProtocolMessageType('CbCrossProcessOpenMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBCROSSPROCESSOPENMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbCrossProcessOpenMsg)
  ))
_sym_db.RegisterMessage(CbCrossProcessOpenMsg)

CbCreateRemoteThreadMsg = _reflection.GeneratedProtocolMessageType('CbCreateRemoteThreadMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBCREATEREMOTETHREADMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbCreateRemoteThreadMsg)
  ))
_sym_db.RegisterMessage(CbCreateRemoteThreadMsg)

CbCrossProcessMsg = _reflection.GeneratedProtocolMessageType('CbCrossProcessMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBCROSSPROCESSMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbCrossProcessMsg)
  ))
_sym_db.RegisterMessage(CbCrossProcessMsg)

CbProcessBlockedMsg = _reflection.GeneratedProtocolMessageType('CbProcessBlockedMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBPROCESSBLOCKEDMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbProcessBlockedMsg)
  ))
_sym_db.RegisterMessage(CbProcessBlockedMsg)

CbNetConnBlockedMsg = _reflection.GeneratedProtocolMessageType('CbNetConnBlockedMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBNETCONNBLOCKEDMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbNetConnBlockedMsg)
  ))
_sym_db.RegisterMessage(CbNetConnBlockedMsg)

CbStatisticsMsg = _reflection.GeneratedProtocolMessageType('CbStatisticsMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBSTATISTICSMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbStatisticsMsg)
  ))
_sym_db.RegisterMessage(CbStatisticsMsg)

CbModuleInfoMsg = _reflection.GeneratedProtocolMessageType('CbModuleInfoMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBMODULEINFOMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbModuleInfoMsg)
  ))
_sym_db.RegisterMessage(CbModuleInfoMsg)

CbVtWriteMsg = _reflection.GeneratedProtocolMessageType('CbVtWriteMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBVTWRITEMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbVtWriteMsg)
  ))
_sym_db.RegisterMessage(CbVtWriteMsg)

CbVtLoadMsg = _reflection.GeneratedProtocolMessageType('CbVtLoadMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBVTLOADMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbVtLoadMsg)
  ))
_sym_db.RegisterMessage(CbVtLoadMsg)

CbEndpointEnvironmentMsg = _reflection.GeneratedProtocolMessageType('CbEndpointEnvironmentMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBENDPOINTENVIRONMENTMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbEndpointEnvironmentMsg)
  ))
_sym_db.RegisterMessage(CbEndpointEnvironmentMsg)

CbServerEnvironmentMsg = _reflection.GeneratedProtocolMessageType('CbServerEnvironmentMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBSERVERENVIRONMENTMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbServerEnvironmentMsg)
  ))
_sym_db.RegisterMessage(CbServerEnvironmentMsg)

CbEnvironmentMsg = _reflection.GeneratedProtocolMessageType('CbEnvironmentMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBENVIRONMENTMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbEnvironmentMsg)
  ))
_sym_db.RegisterMessage(CbEnvironmentMsg)

CbTamperAlertMsg = _reflection.GeneratedProtocolMessageType('CbTamperAlertMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBTAMPERALERTMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbTamperAlertMsg)
  ))
_sym_db.RegisterMessage(CbTamperAlertMsg)

CbEmetMitigationAction = _reflection.GeneratedProtocolMessageType('CbEmetMitigationAction', (_message.Message,), dict(
  DESCRIPTOR = _CBEMETMITIGATIONACTION,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbEmetMitigationAction)
  ))
_sym_db.RegisterMessage(CbEmetMitigationAction)

CbEmetMitigationMsg = _reflection.GeneratedProtocolMessageType('CbEmetMitigationMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBEMETMITIGATIONMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbEmetMitigationMsg)
  ))
_sym_db.RegisterMessage(CbEmetMitigationMsg)

CbProcessMetadataMsg = _reflection.GeneratedProtocolMessageType('CbProcessMetadataMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBPROCESSMETADATAMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbProcessMetadataMsg)
  ))
_sym_db.RegisterMessage(CbProcessMetadataMsg)

CbEventMsg = _reflection.GeneratedProtocolMessageType('CbEventMsg', (_message.Message,), dict(
  DESCRIPTOR = _CBEVENTMSG,
  __module__ = 'sensor_events_pb2'
  # @@protoc_insertion_point(class_scope:CbEventMsg)
  ))
_sym_db.RegisterMessage(CbEventMsg)


# @@protoc_insertion_point(module_scope)
